==> open-cluster-management-cluster-model-5.12.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PlacementBuilder extends io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementFluentImpl<io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement,io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementBuilder>{
  public PlacementBuilder() {
    this(false);
  }
  public PlacementBuilder(java.lang.Boolean validationEnabled) {
    this(new Placement(), validationEnabled);
  }
  public PlacementBuilder(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementFluent<?> fluent) {
    this(fluent, false);
  }
  public PlacementBuilder(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Placement(), validationEnabled);
  }
  public PlacementBuilder(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementFluent<?> fluent,io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement instance) {
    this(fluent, instance, false);
  }
  public PlacementBuilder(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementFluent<?> fluent,io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public PlacementBuilder(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement instance) {
    this(instance,false);
  }
  public PlacementBuilder(io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.PlacementFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.cluster.v1alpha1.Placement build() {
    Placement buildable = new Placement(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementBuilder that = (PlacementBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-cluster-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PlacementBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PlacementBuilder extends PlacementFluentImpl<PlacementBuilder> implements VisitableBuilder<Placement,PlacementBuilder>{
  public PlacementBuilder() {
    this(false);
  }
  public PlacementBuilder(Boolean validationEnabled) {
    this(new Placement(), validationEnabled);
  }
  public PlacementBuilder(PlacementFluent<?> fluent) {
    this(fluent, false);
  }
  public PlacementBuilder(PlacementFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Placement(), validationEnabled);
  }
  public PlacementBuilder(PlacementFluent<?> fluent,Placement instance) {
    this(fluent, instance, false);
  }
  public PlacementBuilder(PlacementFluent<?> fluent,Placement instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public PlacementBuilder(Placement instance) {
    this(instance,false);
  }
  public PlacementBuilder(Placement instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  PlacementFluent<?> fluent;
  Boolean validationEnabled;
  public Placement build() {
    Placement buildable = new Placement(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
